@@ -2,7 +2,7 @@
 *                               dlgIndividual.cpp
 *                             -------------------
 *
-*    Revision     : $Id: dlgIndividual.cpp 437926 2005-07-23 16:15:24Z pino $
+*    Revision     : $Id: dlgIndividual.cpp 530904 2006-04-18 00:26:19Z rohanpm $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -43,6 +43,7 @@
 #include <klocale.h>
 #include <ktoolbar.h>
 #include <krun.h>
+#include <kio/global.h>
 #include "common.h"
 
 #include "transfer.h"
@@ -197,6 +198,7 @@ DlgIndividual::DlgIndividual(Transfer * _item)
     slotToggleAdvanced();
 
     resize( minimumSizeHint() );
+    setMaximumHeight( height() );
 
     //bool keepOpenChecked = false;
     //bool noCaptionYet = true;
@@ -206,7 +208,7 @@ DlgIndividual::DlgIndividual(Transfer * _item)
 }
 
 
-void DlgIndividual::setTotalSize(unsigned long bytes)
+void DlgIndividual::setTotalSize(KIO::filesize_t bytes)
 {
     m_iTotalSize = bytes;
 }
@@ -220,24 +222,16 @@ void DlgIndividual::setPercent(unsigned long percent)
 }
 
 
-void DlgIndividual::setProcessedSize(unsigned long bytes)
+void DlgIndividual::setProcessedSize(KIO::filesize_t bytes)
 {
     sizeLabel->setText(i18n("%1 of %2").arg(KIO::convertSize(bytes)).arg(KIO::convertSize(m_iTotalSize)));
 }
 
 
-void DlgIndividual::setSpeed(unsigned long bytes_per_second, QTime remaining)
+void DlgIndividual::setSpeed(QString speed)
 {
-    QString msg;
-    if (bytes_per_second == 0 && item->getStatus() < Transfer::ST_RUNNING)
-        msg=i18n("Stalled");
-    else if (bytes_per_second == 0 && item->getStatus() == Transfer::ST_FINISHED)
-        msg=i18n("Finished");
-    else
-        msg=i18n("%1/s ( %2 )").arg(KIO::convertSize(bytes_per_second)).arg(remaining.toString());
-
-    speedLabel->setText(msg);
-    m_pDockIndividual->setTip(msg);
+    speedLabel->setText(speed);
+    m_pDockIndividual->setTip(speed);
 }
 
 
