@@ -32,7 +32,9 @@
 #include "kopetemetacontact.h"
 #include "kopetecontactlist.h"
 #include "kopetegroup.h"
+#include "kopetepassword.h"
 #include "kopeteuiglobal.h"
+#include "kopeteglobal.h"
 
 #include <kpassdlg.h>
 #include <kconfig.h>
@@ -63,7 +65,7 @@ public:
 	GaduDCC*	gaduDcc_;
 
 	QTimer*		pingTimer_;
-
+	
 	QTextCodec*	textcodec_;
 	KFileDialog*	saveListDialog;
 	KFileDialog*	loadListDialog;
@@ -81,26 +83,40 @@ public:
 
 	QString		lastDescription;
 	bool		forFriends;
-
-	QPtrList<GaduCommand>		commandList_;
-	KopeteOnlineStatus		status_;
-	QValueList<QHostAddress>	servers_;
+	bool		ignoreAnons;
+        
+	QTimer*         exportTimer_;
+	bool		exportUserlist;
+	
+	KConfigGroup*			config;
+	Kopete::OnlineStatus		status;
+	QValueList<unsigned int>	servers;
 	KGaduLoginParams		loginInfo;
 };
 
-// FIXME: use dynamic cache please, i consider this as broken resolution of this problem
+// 10s is enough ;p
+#define USERLISTEXPORT_TIMEOUT (10*1000)
 
-static const int NUM_SERVERS = 5;
-static const char* const servers_ip[ NUM_SERVERS ] = {
-	"217.17.41.88",
- 	"217.17.41.85",
-	"217.17.41.87",
-	"217.17.41.86",
+// FIXME: use dynamic cache please, i consider this as broken resolution of this problem
+static const char* const servers_ip[] = {
+	"217.17.41.82",
+	"217.17.41.83",
 	"217.17.41.84",
+	"217.17.41.85",
+	"217.17.41.86",
+	"217.17.41.87",
+	"217.17.41.88",
+	"217.17.41.92",
+	"217.17.41.93",
+	"217.17.45.133",
+	"217.17.45.143",
+	"217.17.45.144"
 };
 
- GaduAccount::GaduAccount( KopeteProtocol* parent, const QString& accountID,const char* name )
-: KopeteAccount( parent, accountID, name )
+#define NUM_SERVERS (sizeof(servers_ip)/sizeof(char*))
+
+ GaduAccount::GaduAccount( Kopete::Protocol* parent, const QString& accountID,const char* name )
+: Kopete::PasswordedAccount( parent, accountID, 0, name )
 {
 	QHostAddress ip;
 	p = new GaduAccountPrivate;
@@ -115,14 +131,15 @@ static const char* const servers_ip[ NUM_SERVERS ] = {
 
 	KGlobal::config()->setGroup( "Gadu" );
 
-	setMyself( new GaduContact(  accountId().toInt(), accountId(), this, new KopeteMetaContact() ) );
+	setMyself( new GaduContact( accountId().toInt(), accountId(), this, Kopete::ContactList::self()->myself() ) );
 
-	p->status_ = GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL );
+	p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
 	p->lastDescription = QString::null;
 
-	for ( int i = 0; i < NUM_SERVERS; i++ ) {
+	for ( unsigned int i = 0; i < NUM_SERVERS ; i++ ) {
 		ip.setAddress( QString( servers_ip[i] ) );
-		p->servers_.append( ip );
+		p->servers.append( htonl( ip.toIPv4Address() ) );
+		kdDebug( 14100 ) << "adding IP: " <<  p->servers[ i ] << " to cache" << endl;
 	}
 	p->currentServer = -1;
 	p->serverIP = 0;
@@ -132,16 +149,31 @@ static const char* const servers_ip[ NUM_SERVERS ] = {
 	p->loginInfo.useTls		= false;
 	p->loginInfo.status		= GG_STATUS_AVAIL;
 	p->loginInfo.server		= 0;
-	p->loginInfo.forFriends		= false;
 	p->loginInfo.client_port	= 0;
 	p->loginInfo.client_addr	= 0;
-	
-	p->pingTimer_ = new QTimer( this );
 
+	p->pingTimer_ = new QTimer( this );
+	p->exportTimer_ = new QTimer( this );
+
+	p->exportUserlist = false;
 	p->gaduDcc_ = NULL;
 
-	initActions();
+	p->config = configGroup();
+
+	p->ignoreAnons = ignoreAnons();
+	p->forFriends = loadFriendsMode();
+
 	initConnections();
+	initActions();
+
+	QString nick = p->config->readEntry( QString::fromAscii( "nickName" ) );
+	if ( !nick.isNull() ) {
+		myself()->setProperty( Kopete::Global::Properties::self()->nickName(), nick );
+	}
+	else {
+		myself()->setProperty( Kopete::Global::Properties::self()->nickName(), accountId() );
+		p->config->writeEntry( QString::fromAscii( "nickName" ), accountId() );
+	}
 }
 
 GaduAccount::~GaduAccount()
@@ -163,6 +195,8 @@ GaduAccount::initActions()
 	p->friendsModeAction	= new KToggleAction( i18n( "Only for Friends" ), "", 0,
 							this, SLOT( slotFriendsMode() ), this,
 							"actionFriendsMode" );
+
+	static_cast<KToggleAction*>(p->friendsModeAction)->setChecked( p->forFriends );
 }
 
 void
@@ -172,39 +206,30 @@ GaduAccount::initConnections()
 				SLOT( error( const QString&, const QString& ) ) );
 	QObject::connect( p->session_, SIGNAL( messageReceived( KGaduMessage* ) ),
 				SLOT( messageReceived( KGaduMessage* ) )  );
-	QObject::connect( p->session_, SIGNAL( notify( KGaduNotifyList* ) ),
-				SLOT( notify( KGaduNotifyList* ) ) );
 	QObject::connect( p->session_, SIGNAL( contactStatusChanged( KGaduNotify* ) ),
 				SLOT( contactStatusChanged( KGaduNotify* ) ) );
 	QObject::connect( p->session_, SIGNAL( connectionFailed( gg_failure_t )),
 				SLOT( connectionFailed( gg_failure_t ) ) );
 	QObject::connect( p->session_, SIGNAL( connectionSucceed( ) ),
 				SLOT( connectionSucceed( ) ) );
-	QObject::connect( p->session_, SIGNAL( disconnect( KopeteAccount::DisconnectReason ) ),
-				SLOT( slotSessionDisconnect( KopeteAccount::DisconnectReason ) ) );
+	QObject::connect( p->session_, SIGNAL( disconnect( Kopete::Account::DisconnectReason ) ),
+				SLOT( slotSessionDisconnect( Kopete::Account::DisconnectReason ) ) );
 	QObject::connect( p->session_, SIGNAL( ackReceived( unsigned int ) ),
 				SLOT( ackReceived( unsigned int ) ) );
-	QObject::connect( p->session_, SIGNAL( pubDirSearchResult( const SearchResult& ) ),
-				SLOT( slotSearchResult( const SearchResult& ) ) );
+	QObject::connect( p->session_, SIGNAL( pubDirSearchResult( const SearchResult&, unsigned int  ) ),
+				SLOT( slotSearchResult( const SearchResult&, unsigned int ) ) );
 	QObject::connect( p->session_, SIGNAL( userListExported() ),
 				SLOT( userListExportDone() ) );
 	QObject::connect( p->session_, SIGNAL( userListRecieved( const QString& ) ),
 				SLOT( userlist( const QString& ) ) );
 	QObject::connect( p->session_, SIGNAL( incomingCtcp( unsigned int ) ),
 				SLOT( slotIncomingDcc( unsigned int ) ) );
-	
+
 	QObject::connect( p->pingTimer_, SIGNAL( timeout() ),
 				SLOT( pingServer() ) );
-}
 
-void
-GaduAccount::loaded()
-{
-	QString nick;
-	nick	= pluginData( protocol(), QString::fromAscii( "nickName" ) );
-	if ( !nick.isNull() ) {
-		myself()->rename( nick );
-	}
+	QObject::connect( p->exportTimer_, SIGNAL( timeout() ),
+				SLOT( slotUserlistSynch() ) );
 }
 
 void
@@ -228,10 +253,9 @@ GaduAccount::actionMenu()
 	kdDebug(14100) << "actionMenu() " << endl;
 
 	p->actionMenu_ = new KActionMenu( accountId(), myself()->onlineStatus().iconFor( this ), this );
-
 	p->actionMenu_->popupMenu()->insertTitle( myself()->onlineStatus().iconFor( myself() ), i18n( "%1 <%2> " ).
+	    arg( myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString(), accountId() ) );
 
-	arg( myself()->displayName(), accountId() ) );
 	if ( p->session_->isConnected() ) {
 		p->searchAction->setEnabled( TRUE );
 		p->listputAction->setEnabled( TRUE );
@@ -263,21 +287,23 @@ GaduAccount::actionMenu()
 	else {
 		p->listFromFileAction->setEnabled( TRUE );
 	}
-
 	p->actionMenu_->insert( new KAction( i18n( "Go O&nline" ),
-			GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ).iconFor( this ),
-			0, this, SLOT( slotGoOnline() ), this, "actionGaduConnect" ) );
+				GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ).iconFor( this ),
+				0, this, SLOT( slotGoOnline() ), this, "actionGaduConnect" ) );
+
 	p->actionMenu_->insert( new KAction( i18n( "Set &Busy" ),
-			GaduProtocol::protocol()->convertStatus( GG_STATUS_BUSY ).iconFor( this ),
-			0, this, SLOT( slotGoBusy() ), this, "actionGaduConnect" ) );
+				GaduProtocol::protocol()->convertStatus( GG_STATUS_BUSY ).iconFor( this ),
+				0, this, SLOT( slotGoBusy() ), this, "actionGaduConnect" ) );
+
 	p->actionMenu_->insert( new KAction( i18n( "Set &Invisible" ),
-			GaduProtocol::protocol()->convertStatus( GG_STATUS_INVISIBLE ).iconFor( this ),
-			0, this, SLOT( slotGoInvisible() ), this, "actionGaduConnect" ) );
+				GaduProtocol::protocol()->convertStatus( GG_STATUS_INVISIBLE ).iconFor( this ),
+				0, this, SLOT( slotGoInvisible() ), this, "actionGaduConnect" ) );
+
 	p->actionMenu_->insert( new KAction( i18n( "Go &Offline" ),
-			GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ).iconFor( this ),
-			0, this, SLOT( slotGoOffline() ), this, "actionGaduConnect" ) );
-	p->actionMenu_->insert( new KAction( i18n( "Set &Description..." ),
-			"info",
+				GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ).iconFor( this ),
+				0, this, SLOT( slotGoOffline() ), this, "actionGaduConnect" ) );
+
+	p->actionMenu_->insert( new KAction( i18n( "Set &Description..." ), "info",
 			0, this, SLOT( slotDescription() ), this, "actionGaduDescription" ) );
 
 	p->actionMenu_->insert( p->friendsModeAction );
@@ -299,17 +325,21 @@ GaduAccount::actionMenu()
 }
 
 void
-GaduAccount::connect()
+GaduAccount::connectWithPassword(const QString& password)
 {
-	slotGoOnline();
+	if (password.isEmpty()) {
+		return;
+	}
+	if (isConnected ())
+		return;
+	// FIXME: add status description to this mechainsm, this is a hack now. libkopete design issue.
+	changeStatus( initialStatus(), p->lastDescription );
 }
 
 void
 GaduAccount::disconnect()
 {
-	slotGoOffline();
-	p->connectWithSSL = true;
-	KopeteAccount::disconnect( Manual );
+	disconnect( Manual );
 }
 
 void
@@ -317,28 +347,59 @@ GaduAccount::disconnect( DisconnectReason reason )
 {
 	slotGoOffline();
 	p->connectWithSSL = true;
-	KopeteAccount::disconnect( reason );
+	Kopete::Account::disconnected( reason );
+}
+
+void
+GaduAccount::setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason )
+{
+	kdDebug(14100) << k_funcinfo << "Called" << endl;
+	changeStatus( status, reason);
+}
+
+void
+GaduAccount::slotUserlistSynch()
+{
+	if ( !p->exportUserlist ) {
+		return;
+	}
+	p->exportUserlist = false;
+	kdDebug(14100) << "userlist changed, exporting" << endl;
+	slotExportContactsList();
+}
+
+void
+GaduAccount::userlistChanged()
+{
+	p->exportUserlist = true;
+	p->exportTimer_->changeInterval( USERLISTEXPORT_TIMEOUT );
 }
 
 bool
-GaduAccount::addContactToMetaContact( const QString& contactId, const QString& displayName,
-					 KopeteMetaContact* parentContact )
+GaduAccount::createContact( const QString& contactId, Kopete::MetaContact* parentContact )
 {
-	kdDebug(14100) << "addContactToMetaContact " << contactId << endl;
+	kdDebug(14100) << "createContact " << contactId << endl;
 
 	uin_t uinNumber = contactId.toUInt();
-	GaduContact* newContact = new GaduContact( uinNumber, displayName, this, parentContact );
+	GaduContact* newContact = new GaduContact( uinNumber, parentContact->displayName(),this, parentContact );
 	newContact->setParentIdentity( accountId() );
 	addNotify( uinNumber );
 
+	userlistChanged();
+	
 	return true;
 }
 
 void
-GaduAccount::changeStatus( const KopeteOnlineStatus& status, const QString& descr )
+GaduAccount::changeStatus( const Kopete::OnlineStatus& status, const QString& descr )
 {
-	kdDebug(14101) << "### Status = " << p->session_->isConnected() << endl;
+	unsigned int ns;
+	
+	kdDebug(14100) << "##### change status #####" << endl;
+	kdDebug(14100) << "### Status = " << p->session_->isConnected() << endl;
+	kdDebug(14100) << "### Status description = \"" << descr << "\"" << endl;
 
+	// if change to not available, log off
 	if ( GG_S_NA( status.internalStatus() ) ) {
 		if ( !p->session_->isConnected() ) {
 			return;//already logged off
@@ -354,23 +415,46 @@ GaduAccount::changeStatus( const KopeteOnlineStatus& status, const QString& desc
 		dccOff();
 	}
 	else {
+		// if status is for no desc, but we get some desc, than convert it to status with desc
+		if (!descr.isEmpty() && !GaduProtocol::protocol()->statusWithDescription( status.internalStatus() ) ) {
+			// and rerun us again. This won't cause any recursive call, as both conversions are static
+			ns = GaduProtocol::protocol()->statusToWithDescription( status );
+			changeStatus( GaduProtocol::protocol()->convertStatus( ns ), descr );
+			return;
+		}
+
+		// well, if it's empty but we want to set status with desc, change it too
+                if (descr.isEmpty() && GaduProtocol::protocol()->statusWithDescription( status.internalStatus() ) ) {
+			ns = GaduProtocol::protocol()->statusToWithoutDescription( status );
+			changeStatus( GaduProtocol::protocol()->convertStatus( ns ), descr );
+			return;
+		}
+				
 		if ( !p->session_->isConnected() ) {
+			if ( password().cachedValue().isEmpty() ) {
+				// FIXME: when status string added to connect(), use it here
+				p->lastDescription = descr;
+				connect( status/*, descr*/ );
+				return;
+			}
+
 			if ( useTls() != TLS_no ) {
 				p->connectWithSSL = true;
 			}
 			else {
 				p->connectWithSSL = false;
 			}
+			dccOn();
 			p->serverIP = 0;
 			p->currentServer = -1;
-			p->status_ = status;
+			p->status = status;
 			kdDebug(14100) << "#### Connecting..., tls option "<< (int)useTls() << " " << endl;
 			p->lastDescription = descr;
 			slotLogin( status.internalStatus(), descr );
 			return;
 		}
 		else {
-			p->status_ = status;
+			p->status = status;
 			if ( descr.isEmpty() ) {
 				if ( p->session_->changeStatus( status.internalStatus(), p->forFriends ) != 0 )
 					return;
@@ -390,6 +474,7 @@ GaduAccount::changeStatus( const KopeteOnlineStatus& status, const QString& desc
 			p->pingTimer_->stop();
 		}
 	}
+	p->lastDescription = descr;
 }
 
 void
@@ -401,15 +486,16 @@ GaduAccount::slotLogin( int status, const QString& dscr )
 	myself()->setProperty( GaduProtocol::protocol()->propAwayMessage, dscr );
 
 	if ( !p->session_->isConnected() ) {
-		if ( password().isEmpty() ) {
+		if ( password().cachedValue().isEmpty() ) {
 			connectionFailed( GG_FAILURE_PASSWORD );
 		}
 		else {
-			p->loginInfo.password		= password();
+			p->loginInfo.password		= password().cachedValue();
 			p->loginInfo.useTls		= p->connectWithSSL;
 			p->loginInfo.status		= status;
 			p->loginInfo.statusDescr	= dscr;
 			p->loginInfo.forFriends		= p->forFriends;
+			p->loginInfo.server		= p->serverIP;
 			if ( dccEnabled() ) {
 				p->loginInfo.client_addr	= gg_dcc_ip;
 				p->loginInfo.client_port	= gg_dcc_port;
@@ -429,9 +515,9 @@ GaduAccount::slotLogin( int status, const QString& dscr )
 void
 GaduAccount::slotLogoff()
 {
-	if ( p->session_->isConnected() || p->status_ == GaduProtocol::protocol()->convertStatus( GG_STATUS_CONNECTING )) {
-		p->status_ = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
-		changeStatus( p->status_ );
+	if ( p->session_->isConnected() || p->status == GaduProtocol::protocol()->convertStatus( GG_STATUS_CONNECTING )) {
+		p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
+		changeStatus( p->status );
 		p->session_->logoff();
 		dccOff();
 	}
@@ -440,7 +526,6 @@ GaduAccount::slotLogoff()
 void
 GaduAccount::slotGoOnline()
 {
-	dccOn();
 	changeStatus( GaduProtocol::protocol()->convertStatus( GG_STATUS_AVAIL ) );
 }
 void
@@ -468,6 +553,7 @@ GaduAccount::removeContact( const GaduContact* c )
 	if ( isConnected() ) {
 		const uin_t u = c->uin();
 		p->session_->removeNotify( u );
+		userlistChanged();
 	}
 }
 
@@ -488,7 +574,7 @@ GaduAccount::notify( uin_t* userlist, int count )
 }
 
 void
-GaduAccount::sendMessage( uin_t recipient, const KopeteMessage& msg, int msgClass )
+GaduAccount::sendMessage( uin_t recipient, const Kopete::Message& msg, int msgClass )
 {
 	if ( p->session_->isConnected() ) {
 		p->session_->sendMessage( recipient, msg, msgClass );
@@ -505,10 +591,9 @@ void
 GaduAccount::messageReceived( KGaduMessage* gaduMessage )
 {
 	GaduContact* contact = 0;
-	KopeteContactPtrList contactsListTmp;
+	QPtrList<Kopete::Contact> contactsListTmp;
 
 	// FIXME:check for ignored users list
-	// FIXME:anonymous (those not on the list) users should be ignored, as an option
 
 	if ( gaduMessage->sender_id == 0 ) {
 		//system message, display them or not?
@@ -519,16 +604,20 @@ GaduAccount::messageReceived( KGaduMessage* gaduMessage )
 	contact = static_cast<GaduContact*> ( contacts()[ QString::number( gaduMessage->sender_id ) ] );
 
 	if ( !contact ) {
-		KopeteMetaContact* metaContact = new KopeteMetaContact ();
+		if ( p->ignoreAnons == true ) {
+			return;
+		}
+
+		Kopete::MetaContact* metaContact = new Kopete::MetaContact ();
 		metaContact->setTemporary ( true );
 		contact = new GaduContact( gaduMessage->sender_id,
 				QString::number( gaduMessage->sender_id ), this, metaContact );
-		KopeteContactList::contactList ()->addMetaContact( metaContact );
+		Kopete::ContactList::self ()->addMetaContact( metaContact );
 		addNotify( gaduMessage->sender_id );
 	}
 
 	contactsListTmp.append( myself() );
-	KopeteMessage msg( gaduMessage->sendTime, contact, contactsListTmp, gaduMessage->message, KopeteMessage::Inbound, KopeteMessage::RichText );
+	Kopete::Message msg( gaduMessage->sendTime, contact, contactsListTmp, gaduMessage->message, Kopete::Message::Inbound, Kopete::Message::RichText );
 	contact->messageReceived( msg );
 }
 
@@ -547,20 +636,6 @@ GaduAccount::ackReceived( unsigned int recipient  )
 	}
 }
 
-
-void
-GaduAccount::notify( KGaduNotifyList* notifyList )
-{
-	QPtrListIterator<KGaduNotify>notifyListIterator( *notifyList );
-	unsigned int i;
-
-	for ( i = notifyList->count() ; i-- ; ++notifyListIterator ) {
-		kdDebug(14100) << "### NOTIFY " << (*notifyListIterator)->contact_id << " " << (*notifyListIterator)->status << endl;
-		contactStatusChanged( (*notifyListIterator) );
-	}
-}
-
-
 void
 GaduAccount::contactStatusChanged( KGaduNotify* gaduNotify )
 {
@@ -599,22 +674,12 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 
 	switch (failure) {
 		case GG_FAILURE_PASSWORD:
-			pass = password( true );
-			if ( pass.isEmpty() ) {
-				slotCommandDone( QString::null, i18n( "Please set password, empty passwords are not supported by Gadu-Gadu"  ) );
-				// and set status disconnected, so icon on toolbar won't blink
-				p->status_ = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
-				myself()->setOnlineStatus( p->status_ );
-				return;
-			}
-			if ( pass.isNull() ){
-				// user pressed CANCEL
-				p->status_ = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
-				myself()->setOnlineStatus( p->status_ );
-				return;
-			}
-			tryReconnect = true;
-		break;
+			password().setWrong();
+			// user pressed CANCEL
+			p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
+			myself()->setOnlineStatus( p->status );
+			disconnected( BadPassword );
+			return;
 		default:
 			if ( p->connectWithSSL ) {
 				if ( useTls() != TLS_only ) {
@@ -628,13 +693,14 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 				}
 			}
 			else {
-				if ( p->currentServer == NUM_SERVERS-1 ) {
+				if ( p->currentServer == NUM_SERVERS - 1 ) {
 					p->serverIP = 0;
 					p->currentServer = -1;
+					kdDebug(14100) << "trying : " << "IP from hub " << endl;
 				}
 				else {
-					p->serverIP = htonl( p->servers_[ ++p->currentServer ].ip4Addr() );
-					kdDebug(14100) << "trying : " << p->currentServer << endl;
+					p->serverIP = p->servers[ ++p->currentServer ];
+					kdDebug(14100) << "trying : " << p->currentServer << " IP " << p->serverIP << endl;
 					tryReconnect = true;
 				}
 			}
@@ -642,13 +708,14 @@ GaduAccount::connectionFailed( gg_failure_t failure )
 	}
 
 	if ( tryReconnect ) {
-			slotLogin( p->status_.internalStatus() , p->lastDescription );
+			slotLogin( p->status.internalStatus() , p->lastDescription );
 	}
 	else {
 		error( i18n( "unable to connect to the Gadu-Gadu server(\"%1\")." ).arg( GaduSession::failureDescription( failure ) ),
 				i18n( "Connection Error" ) );
-		p->status_ = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
-		myself()->setOnlineStatus( p->status_ );
+		p->status = GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL );
+		myself()->setOnlineStatus( p->status );
+		disconnected( InvalidHost );
 	}
 }
 
@@ -678,51 +745,50 @@ GaduAccount::dccOff()
 }
 
 void
-GaduAccount::slotIncomingDcc( unsigned int UIN )
+GaduAccount::slotIncomingDcc( unsigned int uin )
 {
 	GaduContact* contact;
 	GaduDCCTransaction* trans;
-	gg_dcc* dcc;
 
-	if ( !UIN ) {
+	if ( !uin ) {
 		return;
 	}
 
-	contact = static_cast<GaduContact*>( contacts()[ QString::number( UIN ) ] );
+	contact = static_cast<GaduContact*>( contacts()[ QString::number( uin ) ] );
 
 	if ( !contact ) {
+	  kdDebug(14100) << "attempt to make dcc connection from unknown uin " << uin << endl;
 		return;
 	}
 
 	// if incapabile to transfer files, forget about it.
 	if ( contact->contactPort() < 10 ) {
-		return;
+	  kdDebug(14100) << "can't respond to " << uin << " request, his listeing port is too low" << endl;
+	  return;
 	}
-	
-	dcc = gg_dcc_get_file( htonl( contact->contactIp().ip4Addr() ), contact->contactPort(), p->loginInfo.uin ,UIN );
-	
-	if ( !dcc) {
-		kdDebug(14100) << "gg_dcc_get_file failed" << endl;
-		return;
-	}
-	
-	trans = new GaduDCCTransaction( dcc, contact, p->gaduDcc_ );
-	if ( trans->setupIncoming( UIN ) == false ) {
+
+	trans = new GaduDCCTransaction( p->gaduDcc_ );
+	if ( trans->setupIncoming( p->loginInfo.uin, contact ) == false ) {
 		delete trans;
 	}
+
 }
 
 void
 GaduAccount::connectionSucceed( )
 {
 	kdDebug(14100) << "#### Gadu-Gadu connected! " << endl;
-	p->status_ =  GaduProtocol::protocol()->convertStatus( p->session_->status() );
-	myself()->setOnlineStatus( p->status_ );
+	p->status =  GaduProtocol::protocol()->convertStatus( p->session_->status() );
+	myself()->setOnlineStatus( p->status );
 	myself()->setProperty( GaduProtocol::protocol()->propAwayMessage, p->lastDescription );
 	startNotify();
 
 	p->session_->requestContacts();
-	p->pingTimer_->start( 180000 );//3 minute timeout
+	p->pingTimer_->start( 3*60*1000 );//3 minute timeout
+	pingServer();
+
+	// check if we need to export userlist every USERLISTEXPORT_TIMEOUT ms
+	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 void
@@ -733,7 +799,7 @@ GaduAccount::startNotify()
 		return;
 	}
 
-	QDictIterator<KopeteContact> kopeteContactsList( contacts() );
+	QDictIterator<Kopete::Contact> kopeteContactsList( contacts() );
 
 	uin_t* userlist = 0;
 	userlist = new uin_t[ contacts().count() ];
@@ -747,7 +813,7 @@ GaduAccount::startNotify()
 }
 
 void
-GaduAccount::slotSessionDisconnect( KopeteAccount::DisconnectReason reason )
+GaduAccount::slotSessionDisconnect( Kopete::Account::DisconnectReason reason )
 {
 	uin_t status;
 
@@ -756,15 +822,11 @@ GaduAccount::slotSessionDisconnect( KopeteAccount::DisconnectReason reason )
 	if (p->pingTimer_) {
 		p->pingTimer_->stop();
 	}
-	QDictIterator<KopeteContact> it( contacts() );
 
-	for ( ; it.current() ; ++it ) {
-		static_cast<GaduContact*>((*it))->setOnlineStatus(
-				GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ) );
-	}
+	setAllContactsStatus( GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ) );
 
 	status = myself()->onlineStatus().internalStatus();
-	if ( status != GG_STATUS_NOT_AVAIL || status!= GG_STATUS_NOT_AVAIL_DESCR ) {
+	if ( status != GG_STATUS_NOT_AVAIL || status != GG_STATUS_NOT_AVAIL_DESCR ) {
 		myself()->setOnlineStatus( GaduProtocol::protocol()->convertStatus( GG_STATUS_NOT_AVAIL ) );
 	}
 	GaduAccount::disconnect( reason );
@@ -779,9 +841,12 @@ GaduAccount::userlist( const QString& contactsListString )
 	QString contactName;
 	QStringList groups;
 	GaduContact* contact;
-	KopeteMetaContact* metaContact;
+	Kopete::MetaContact* metaContact;
 	unsigned int i;
 
+	// don't export any new changes that were just imported :-)
+	p->exportTimer_->stop();
+	
 	for ( i = 0; i != contactsList.size() ; i++ ) {
 		kdDebug(14100) << "uin " << contactsList[i].uin << endl;
 
@@ -795,7 +860,7 @@ GaduAccount::userlist( const QString& contactsListString )
 		}
 		else {
 			contactName = GaduContact::findBestContactName( &contactsList[i] );
-			bool s = addContact( contactsList[i].uin, contactName, 0L, KopeteAccount::DontChangeKABC, QString::null, false );
+			bool s = addContact( contactsList[i].uin, contactName, 0L, Kopete::Account::DontChangeKABC);
 			if ( s == false ) {
 				kdDebug(14100) << "There was a problem adding UIN "<< contactsList[i].uin << "to users list" << endl;
 				continue;
@@ -803,7 +868,7 @@ GaduAccount::userlist( const QString& contactsListString )
 		}
 		contact = static_cast<GaduContact*>( contacts()[ contactsList[i].uin ] );
 		if ( contact == NULL ) {
-			kdDebug(14100) << "oops, no KopeteContact in contacts()[] for some reason, for \"" << contactsList[i].uin << "\"" << endl;
+			kdDebug(14100) << "oops, no Kopete::Contact in contacts()[] for some reason, for \"" << contactsList[i].uin << "\"" << endl;
 			continue;
 		}
 
@@ -814,14 +879,17 @@ GaduAccount::userlist( const QString& contactsListString )
 			// FIXME: libkopete bug i guess, by default contact goes to top level group
 			// if user desrired to see contact somewhere else, remove it from top level one
 			metaContact = contact->metaContact();
-			metaContact->removeFromGroup( KopeteGroup::topLevel() );
+			metaContact->removeFromGroup( Kopete::Group::topLevel() );
 			// put him in all desired groups:
 			groups = QStringList::split( ",", contactsList[i].group );
 			for ( QStringList::Iterator groupsIterator = groups.begin(); groupsIterator != groups.end(); ++groupsIterator ) {
-				metaContact->addToGroup( KopeteContactList::contactList ()->getGroup ( *groupsIterator) );
+				metaContact->addToGroup( Kopete::ContactList::self ()->findGroup ( *groupsIterator) );
 			}
 		}
 	}
+	// start to check if we need to export userlist 
+	p->exportUserlist = false;	
+	p->exportTimer_->start( USERLISTEXPORT_TIMEOUT );
 }
 
 void
@@ -830,14 +898,15 @@ GaduAccount::userListExportDone()
 	slotCommandDone( QString::null, i18n( "Contacts exported to the server.") );
 }
 
-
 void
 GaduAccount::slotFriendsMode()
 {
 	p->forFriends = !p->forFriends;
-	kdDebug( 14100 ) << "for friends mode: " << p->forFriends << endl;
+	kdDebug( 14100 ) << "for friends mode: " << p->forFriends << " desc" << p->lastDescription << endl;
 	// now change status, it will changing it with p->forFriends flag
-	changeStatus( p->status_, p->lastDescription );
+	changeStatus( p->status, p->lastDescription );
+
+	saveFriendsMode( p->forFriends );
 
 }
 
@@ -856,10 +925,11 @@ GaduAccount::slotExportContactsListToFile()
 
 	p->saveListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString::null,
 					Kopete::UI::Global::mainWidget(), "gadu-list-save", false );
-	p->saveListDialog->setCaption( i18n("Save Contacts List for Account %1 As").arg( myself()->displayName() ) );
+	p->saveListDialog->setCaption(
+	    i18n("Save Contacts List for Account %1 As").arg(
+	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->saveListDialog->exec() == QDialog::Accepted ) {
-
 		QCString list = p->textcodec_->fromUnicode( userlist()->asString() );
 
 		if ( tempFile.status() ) {
@@ -890,6 +960,9 @@ GaduAccount::slotExportContactsListToFile()
 void
 GaduAccount::slotImportContactsFromFile()
 {
+	KURL url;
+	QCString list;
+	QString oname;
 
 	if ( p->loadListDialog ) {
 		kdDebug( 14100 ) << "load contacts from file: alread waiting for input " << endl ;
@@ -898,20 +971,14 @@ GaduAccount::slotImportContactsFromFile()
 
 	p->loadListDialog = new KFileDialog( "::kopete-gadu" + accountId(), QString::null,
 					Kopete::UI::Global::mainWidget(), "gadu-list-load", true );
-	p->loadListDialog->setCaption( i18n("Load Contacts List for Account %1 As").arg( myself()->displayName() ) );
+	p->loadListDialog->setCaption(
+	    i18n("Load Contacts List for Account %1 As").arg(
+	    myself()->property( Kopete::Global::Properties::self()->nickName()).value().toString() ) );
 
 	if ( p->loadListDialog->exec() == QDialog::Accepted ) {
-
-		QCString list;
-
-		KURL url = p->loadListDialog->selectedURL();
-		QString oname;
-		kdDebug(14100) << "a:"<<url<<"\nb:" << oname << endl;
-		if ( KIO::NetAccess::download(	url,
-						oname,
-						Kopete::UI::Global::mainWidget()
-						) ) {
-
+		url = p->loadListDialog->selectedURL();
+		kdDebug(14100) << "a:" << url << "\nb:" << oname << endl;
+		if ( KIO::NetAccess::download( url, oname, Kopete::UI::Global::mainWidget() ) ) {
 			QFile tempFile( oname );
 			if ( tempFile.open( IO_ReadOnly ) ) {
 				list = tempFile.readAll();
@@ -939,13 +1006,24 @@ GaduAccount::slotImportContactsFromFile()
 	p->loadListDialog = NULL;
 }
 
+unsigned int
+GaduAccount::getPersonalInformation()
+{
+	return p->session_->getPersonalInformation();
+}
+
+bool 
+GaduAccount::publishPersonalInformation( ResLine& d )
+{
+	return p->session_->publishPersonalInformation( d );
+}
+
 void
 GaduAccount::slotExportContactsList()
 {
 	p->session_->exportContactsOnServer( userlist() );
 }
 
-
 GaduContactsList*
 GaduAccount::userlist()
 {
@@ -957,7 +1035,7 @@ GaduAccount::userlist()
 		return contactsList;
 	}
 
-	QDictIterator<KopeteContact> contactsIterator( contacts() );
+	QDictIterator<Kopete::Contact> contactsIterator( contacts() );
 
 	for( i=0 ; contactsIterator.current() ; ++contactsIterator ) {
 		contact = static_cast<GaduContact*>( *contactsIterator );
@@ -1006,13 +1084,10 @@ GaduAccount::slotDescription()
 	delete away;
 }
 
-bool
-GaduAccount::pubDirSearch( QString& name, QString& surname, QString& nick,
-			    int UIN, QString& city, int gender,
-			    int ageFrom, int ageTo, bool onlyAlive )
+unsigned int
+GaduAccount::pubDirSearch( ResLine& query, int ageFrom, int ageTo, bool onlyAlive )
 {
-	return p->session_->pubDirSearch( name, surname, nick, UIN, city, gender,
-							ageFrom, ageTo, onlyAlive );
+	return p->session_->pubDirSearch( query, ageFrom, ageTo, onlyAlive );
 }
 
 void
@@ -1022,17 +1097,32 @@ GaduAccount::pubDirSearchClose()
 }
 
 void
-GaduAccount::slotSearchResult( const SearchResult& result )
+GaduAccount::slotSearchResult( const SearchResult& result, unsigned int seq )
 {
-	emit pubDirSearchResult( result );
+	emit pubDirSearchResult( result, seq );
+}
+
+void
+GaduAccount::sendFile( GaduContact* peer, QString& filePath )
+{
+	GaduDCCTransaction* gtran = new GaduDCCTransaction( p->gaduDcc_ );
+	gtran->setupOutgoing( peer, filePath );
+}
+
+void
+GaduAccount::dccRequest( GaduContact* peer )
+{
+	if ( peer && p->session_ ) {
+		p->session_->dccRequest( peer->uin() );
+	}
 }
 
 // dcc settings
 bool
 GaduAccount::dccEnabled()
 {
-	QString s = pluginData( protocol(), QString::fromAscii( "useDcc" ) );
-	kdDebug( 14100 ) << "dccEnabled: "<<s<<endl;
+	QString s = p->config->readEntry( QString::fromAscii( "useDcc" ) );
+	kdDebug( 14100 ) << "dccEnabled: "<< s << endl;
 	if ( s == QString::fromAscii( "enabled" ) ) {
 		return true;
 	}
@@ -1053,16 +1143,69 @@ GaduAccount::setDcc( bool d )
 		s = QString::fromAscii( "enabled" );
 	}
 
-	setPluginData( protocol(), QString::fromAscii( "useDcc" ), s );
+	p->config->writeEntry( QString::fromAscii( "useDcc" ), s );
 
-	if ( p->session_->isConnected() & d ) {
+	if ( p->session_->isConnected() && d ) {
 		dccOn();
 	}
+
 	kdDebug( 14100 ) << "s: "<<s<<endl;
 
 	return f;
 }
 
+void
+GaduAccount::saveFriendsMode( bool i )
+{
+	p->config->writeEntry( QString::fromAscii( "forFriends" ), 
+			i == true ? QString::fromAscii( "1" ) : QString::fromAscii( "0" ) );
+}
+
+bool
+GaduAccount::loadFriendsMode()
+{
+	QString s;
+	bool r;
+	int n;
+
+	s = p->config->readEntry( QString::fromAscii( "forFriends" ) );
+	n = s.toInt( &r );
+
+	if ( n ) {
+		return true;
+	}
+
+	return false;
+
+}
+
+// might be bit inconsistent with what I used in DCC, but hell, it is so much easier to parse :-)
+bool
+GaduAccount::ignoreAnons()
+{
+	QString s;
+	bool r;
+	int n;
+	
+	s = p->config->readEntry( QString::fromAscii( "ignoreAnons" ) );
+	n = s.toInt( &r );
+	
+	if ( n ) {
+		return true;
+	}
+
+	return false;
+	
+}
+
+void 
+GaduAccount::setIgnoreAnons( bool i )
+{
+	p->ignoreAnons = i;
+	p->config->writeEntry( QString::fromAscii( "ignoreAnons" ), 
+			i == true ? QString::fromAscii( "1" ) : QString::fromAscii( "0" ) );
+}
+
 GaduAccount::tlsConnection
 GaduAccount::useTls()
 {
@@ -1071,7 +1214,7 @@ GaduAccount::useTls()
 	unsigned int oldC;
 	tlsConnection Tls;
 
-	s = pluginData( protocol(), QString::fromAscii( "useEncryptedConnection" ) );
+	s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ) );
 	oldC = s.toUInt( &c );
 	// we have old format
 	if ( c ) {
@@ -1079,7 +1222,7 @@ GaduAccount::useTls()
 				oldC << " willl be converted to new string value" << endl;
 		setUseTls( (tlsConnection) oldC );
 		// should be string now, unless there was an error reading
-		s = pluginData( protocol(), QString::fromAscii( "useEncryptedConnection" ) );
+		s = p->config->readEntry( QString::fromAscii( "useEncryptedConnection" ) );
 		kdDebug( 14100 ) << "new useEncryptedConnection value : " << s << endl;
 	}
 
@@ -1113,7 +1256,7 @@ GaduAccount::setUseTls( tlsConnection ut )
 		break;
 	}
 
-	setPluginData( protocol(), QString::fromAscii( "useEncryptedConnection" ), s );
+	p->config->writeEntry( QString::fromAscii( "useEncryptedConnection" ), s );
 }
 
 #include "gaduaccount.moc"
