@@ -139,7 +139,8 @@ Interface_wireless_wirelessextensions::get_info (int skfd, const QString& interf
     }
 
   /* Get ESSID */
-  wrq.u.essid.pointer = (caddr_t) WIFI_CONFIG(info,essid);
+  /* prepare NULL-terminated buffer in case the string returned by SIOCGIWESSID is NOT NULL-terminated */
+  memset(wrq.u.essid.pointer, '\0', IW_ESSID_MAX_SIZE + 1);
   wrq.u.essid.length = IW_ESSID_MAX_SIZE + 1;
   wrq.u.essid.flags = 0;
   if (iw_get_ext (skfd, ifname, SIOCGIWESSID, &wrq) >= 0)
@@ -533,14 +534,17 @@ QTable* Interface_wireless_wirelessextensions::get_available_networks ()
 
     *iwlist << iwlist_bin << interface_name << "scanning";
 
-    connect ( iwlist, SIGNAL ( readReady ( KProcIO * ) ), this, SLOT ( parseScanData ( KProcIO * ) ) );
+//    connect ( iwlist, SIGNAL ( readReady ( KProcIO * ) ), this, SLOT ( parseScanData ( KProcIO * ) ) );
 	    
    if ( !iwlist->start ( KProcess::Block ) )
         KMessageBox::sorry ( 0, i18n ( "Unable to perform the scan. Please make sure the executable \"iwlist\" is in your $PATH." ),
 				i18n ( "Scanning not possible" ) );
 
-    // while (iwlist->isRunning()) sleep ( 1 );
+    // this should never happen. But there was a report about Block not being as blocking as it should, so let's be safe about it
+    while (iwlist->isRunning()) sleep ( 1 );
 
+    parseScanData ( iwlist );
+   
     for (int i = 0; i<4; i++ ) networks->adjustColumn(i);
 
     return networks;
@@ -598,17 +602,33 @@ Interface_wireless_wirelessextensions::parseScanData ( KProcIO * iwlist )
         }
       if ( !ignoreRemainingBits && data.contains ( "Encryption key:" ) )
         {
-          if ( data.contains ( "on" ) )
-            networks->setText ( cellcount - 1, 3, QString ( "on" ) );
-          else
+          if ( data.contains ( "off" ) )
             networks->setText ( cellcount - 1, 3, QString ( "off" ) );
+          else
+            networks->setText ( cellcount - 1, 3, QString ( "on" ) );
         }
       if ( !ignoreRemainingBits && data.contains ( "Quality:" ) )
         {
           QString quality = data.mid ( data.find ( ":" ) + 1, data.find ( "/" ) - data.find ( ":" ) - 1 );
           networks->setText ( cellcount - 1, 2, quality );
         }
-
+      
+      if ( !ignoreRemainingBits && data.contains ( "Quality=" ) )
+        {
+          QString quality = data.mid ( data.find ( "=" ) + 1, data.find ( "/" ) - data.find ( "=" ) - 1 );
+          networks->setText ( cellcount - 1, 2, quality );
+        }
+      
+      if ( !ignoreRemainingBits && data.contains ( "wpa_ie" ) )
+	{
+	  networks->setText ( cellcount - 1, 3, QString ( "WPA" ) );
+	}
+      
+      if ( !ignoreRemainingBits && data.contains ( "rsn_ie" ) )
+        {
+          networks->setText ( cellcount - 1, 3, QString ( "WPA2" ) );
+        }
+      
     }
 }
 
